# __all__ = []

# import pkgutil
# import inspect

# for loader, name, is_pkg in pkgutil.walk_packages(__path__):
#     module = loader.find_module(name).load_module(name)

#     for name, value in inspect.getmembers(module):
#         if name.startswith('__'):
#             continue

#         globals()[name] = value
#         __all__.append(name)

from .src import *

__all__ = ['cat_anon', 'cat_lump', 'as_cat', 'cat_collapse',
           'cat_other']
